@@ -3,12 +3,13 @@ Copyright (c) 2025 HIPP developers
 Description: all fixtures for the aerial tests
 """
 
+import glob
 import os
 from collections import namedtuple
 
 import pytest
 
-from hipp.aerial.aerial_preprocessing import AerialPreprocessing
+from hipp.aerial.core import create_fiducial_templates
 from hipp.dataquery import NAGAP_download_images_to_disk
 
 DatasetInfo = namedtuple("DatasetInfo", ["dataset_path", "raw_images"])
@@ -30,8 +31,10 @@ def fiducials(dataset: DatasetInfo) -> str:
     coords_corner = {"fiducial_coordinate": (1115, 381), "subpixel_center_coordinate": (805, 803)}
     coords_midside = {"fiducial_coordinate": (1040, 5881), "subpixel_center_coordinate": (803, 803)}
 
-    preproc = AerialPreprocessing(dataset.raw_images)
-    preproc.create_fiducial_template(corner=True, **coords_corner)  # type: ignore [arg-type]
-    preproc.create_fiducial_template(midside=True, **coords_midside)  # type: ignore [arg-type]
+    first_image_path = sorted(glob.glob(os.path.join(dataset.raw_images, "*.tif")))[0]
+    fiducial_directory = os.path.join(dataset.dataset_path, "fiducial_templates")
 
-    return preproc.fiducials_directory
+    create_fiducial_templates(first_image_path, fiducial_directory, corner=True, **coords_corner)  # type: ignore [arg-type]
+    create_fiducial_templates(first_image_path, fiducial_directory, midside=True, **coords_midside)  # type: ignore [arg-type]
+
+    return fiducial_directory
